from mtpiclick.point import point

bottom = 725
left = 108
top = 41
submenu = 307
subsubmenu = 510

product = point(left, top)
home = point(141, bottom)
login = point(865, top)
menu = point(225, bottom)
start = point(52, bottom)
messages = point(512, bottom)
login_password = point(622, 323)
key_3 = point(244, 347)
key_ok = point(927, 466)
login_ok = point(389, 424)
capture = point(807,864)
frame = point(760, 0)